
History
-------

__0.0.1 (2016-11-02)__: Initial Release of code to GitHub
__0.0.2 (2016-22-03)__: Fix for when no existing aliases exist
__0.0.4 (2016-22-03)__: Initial PyPi Release
__0.0.5 (2016-23-03)__: Fix issue with missing dependencies on pip install